==> ukui-biometric-auth_1.0.3.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Biométrico</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-pid:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Fornecedor:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-pid:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Açao:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Autenticar</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>na autenticação, por favor aguarde ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Um aplicativo está tentando executar uma ação que requer privilégios. A autenticação é necessária para executar esta ação.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Senha: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Autenticação falhou. Por favor, tente novamente.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Outro cliente já está autenticando, por favor, tente novamente mais tarde.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Falha de autenticação, por favor, tente novamente.</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_1.2.0.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Biométrico</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-pid:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Fornecedor:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-pid:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Açao:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Autenticar</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>na autenticação, por favor aguarde ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Um aplicativo está tentando executar uma ação que requer privilégios. A autenticação é necessária para executar esta ação.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Senha: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Autenticação falhou. Por favor, tente novamente.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Outro cliente já está autenticando, por favor, tente novamente mais tarde.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Falha de autenticação, por favor, tente novamente.</translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
